@@ -189,6 +189,7 @@
 #include "shapefil.h"
 #include <R_ext/Arith.h> /* for NA_INTEGER, NA_REAL */
 #include <R_ext/Error.h>
+#include <R_ext/Print.h>
 #include <math.h>
 #include <stdlib.h>
 #include <ctype.h>
@@ -721,16 +722,14 @@ static void *DBFReadAttribute(DBFHandle psDBF, int hEntity, int iField,
 
 	if( fseek( psDBF->fp, nRecordOffset, 0 ) != 0 )
 	{
-	    fprintf( stderr, "fseek(%d) failed on DBF file.\n",
-		     nRecordOffset );
+	    REprintf("fseek(%d) failed on DBF file", nRecordOffset);
 	    return NULL;
 	}
 
 	if( fread( psDBF->pszCurrentRecord, psDBF->nRecordLength,
 		   1, psDBF->fp ) != 1 )
 	{
-	    fprintf( stderr, "fread(%d) failed on DBF file.\n",
-		     psDBF->nRecordLength );
+	    REprintf("fread(%d) failed on DBF file", psDBF->nRecordLength );
 	    return NULL;
 	}
 
